Retrieving timeseries
======================

From points
-----------

PCR-GLOBWB writes output to netCDF4-files. It is thus necessary to have the right tools to read and process the data.

Of particular interest are timeseries of, for instance, discharge to validate model output.

.. autoclass:: sim_data.from_nc
    :members:

    
